@@ -25,6 +25,10 @@
  * \date    	2005
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
  // KDE - Headers
  #include <kaudioplayer.h>
  #include <tdeconfig.h>
@@ -88,18 +92,21 @@ ConfigureDialog::ConfigureDialog( TDEConfig *_config, HardwareInfo *_hwinfo, Set
 
 	// get the correct available suspend types
 	SuspendStates suspend = hwinfo->getSuspendSupport();
-	if( suspend.suspend2ram && (suspend.suspend2ram_allowed || suspend.suspend2ram_allowed == -1)) {
-		actions.append("Suspend to RAM");
-	}
-	if ( suspend.suspend2disk && (suspend.suspend2disk_allowed || suspend.suspend2disk_allowed == -1)) {
-		actions.append("Suspend to Disk");
-	}
 	if ( suspend.freeze && (suspend.freeze_allowed || suspend.freeze_allowed == -1)) {
 		actions.append("Freeze");
 	}
 	if ( suspend.standby && (suspend.standby_allowed || suspend.standby_allowed == -1)) {
 		actions.append("Standby");
 	}
+	if( suspend.suspend2ram && (suspend.suspend2ram_allowed || suspend.suspend2ram_allowed == -1)) {
+		actions.append("Suspend");
+	}
+	if ( suspend.suspend2disk && (suspend.suspend2disk_allowed || suspend.suspend2disk_allowed == -1)) {
+		actions.append("Hibernate");
+	}
+	if ( suspend.suspend_hybrid && (suspend.suspend_hybrid_allowed || suspend.suspend_hybrid_allowed == -1)) {
+		actions.append("Hybrid Suspend");
+	}
 
 	setIcons();
 	setTooltips();
@@ -246,10 +253,10 @@ void ConfigureDialog::setIcons(){
 	tB_scheme->setItemIconSet( 0 ,SmallIcon("tdescreensaver", TQIconSet::Automatic));
 	tB_scheme->setItemIconSet( 1 ,SmallIcon("display", TQIconSet::Automatic));
 
-	if(actions[0] == "Suspend to Disk") {
+	if(actions[0] == "Hibernate") {
 		tB_scheme->setItemIconSet( 2 ,SmallIcon("suspend_to_disk", TQIconSet::Automatic));
 	}
-	else if(actions[0] == "Suspend to RAM") {
+	else if(actions[0] == "Suspend") {
 		tB_scheme->setItemIconSet( 2 ,SmallIcon("suspend_to_ram", TQIconSet::Automatic));
 	}
 	else if(actions[0] == "Freeze") {
@@ -742,7 +749,7 @@ void ConfigureDialog::setGeneralSettings() {
 	// buttons tab:
 	TQStringList _actions = tdeconfig->readListEntry("buttonsAllowedActions", TQString());
 	fillActionComboBox(cB_PowerButton, _actions, tdeconfig->readEntry("ActionOnPowerButton", TQString()));
-	fillActionComboBox(cB_SleepButton, _actions, tdeconfig->readEntry("ActionOnSleepButton", TQString()));
+	fillActionComboBox(cB_SuspendButton, _actions, tdeconfig->readEntry("ActionOnSuspendButton", TQString()));
 	fillActionComboBox(cB_S2DiskButton, _actions, tdeconfig->readEntry("ActionOnS2DiskButton", TQString()));
 	// avoid logout dialog for lidclose - this make no sense
 	_actions.remove("LOGOUT_DIALOG");
@@ -879,7 +886,7 @@ void ConfigureDialog::saveGeneralSettings() {
 	// button tab
 	tdeconfig->writeEntry("ActionOnPowerButton", mapDescriptionToAction(cB_PowerButton->currentText()));
 	tdeconfig->writeEntry("ActionOnLidClose", mapDescriptionToAction(cB_LidcloseButton->currentText()));
-	tdeconfig->writeEntry("ActionOnSleepButton", mapDescriptionToAction(cB_SleepButton->currentText()));
+	tdeconfig->writeEntry("ActionOnSuspendButton", mapDescriptionToAction(cB_SuspendButton->currentText()));
 	tdeconfig->writeEntry("ActionOnS2DiskButton", mapDescriptionToAction(cB_S2DiskButton->currentText()));
 
 	// schemes tab
@@ -1798,11 +1805,14 @@ TQString ConfigureDialog::mapActionToDescription( TQString action ) {
 	} else if (action.startsWith("LOGOUT_DIALOG")) {
 		ret = i18n("Logout Dialog");
 	} else if (action.startsWith("SUSPEND2DISK")) {
-		if (actions.contains("Suspend to Disk"))
-			ret = i18n("Suspend to Disk");
+		if (actions.contains("Hibernate"))
+			ret = i18n("Hibernate");
+	} else if (action.startsWith("SUSPEND_HYBRID")) {
+		if (actions.contains("Hybrid Suspend"))
+			ret = i18n("Hybrid Suspend");
 	} else if (action.startsWith("SUSPEND2RAM")) {
-		if (actions.contains("Suspend to RAM"))
-			ret = i18n("Suspend to RAM");
+		if (actions.contains("Suspend"))
+			ret = i18n("Suspend");
 	} else if (action.startsWith("FREEZE")) {
 		if (actions.contains("Freeze"))
 			ret = i18n("Freeze");
@@ -1839,11 +1849,14 @@ TQString ConfigureDialog::mapDescriptionToAction( TQString description ) {
 	} else if (description.startsWith("Logout Dialog") ||
 		   description.startsWith(i18n("Logout Dialog"))) {
 		ret = "LOGOUT_DIALOG";
-	} else if (description.startsWith("Suspend to Disk") ||
-		   description.startsWith(i18n("Suspend to Disk"))) {
+	} else if (description.startsWith("Hibernate") ||
+		   description.startsWith(i18n("Hibernate"))) {
 		ret = "SUSPEND2DISK";
-	} else if (description.startsWith("Suspend to RAM") ||
-		   description.startsWith(i18n("Suspend to RAM"))) {
+	} else if (description.startsWith("Hybrid Suspend") ||
+		   description.startsWith(i18n("Hybrid Suspend"))) {
+		ret = "SUSPEND_HYBRID";
+	} else if (description.startsWith("Suspend") ||
+		   description.startsWith(i18n("Suspend"))) {
 		ret = "SUSPEND2RAM";
 	} else if (description.startsWith("Freeze") ||
 		   description.startsWith(i18n("Freeze"))) {
