@@ -24,6 +24,10 @@
  * \date    	2006-2007
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // include global header
 #include <fcntl.h>
 
@@ -193,16 +197,13 @@ void HardwareInfo::processKeyPressEvent(unsigned int keycode, TDEEventDevice* ed
 
 	// FIXME
 	// How can I get specific button press/release information (instead of just "something happened to the button") from the TDE hardware library?
-	// TODO: Check if we really need to monitor this events. We get maybe also
-	//	 HAL_PROPERTY_CHANGED event for the key
-// 	if (message.startsWith("ButtonPressed")) {
 		kdDebug() << "ButtonPressed event from TDE HW library " << endl;
 		if (((edevice->eventType() == TDEEventDeviceType::ACPIPowerButton) || (edevice->eventType() == TDEEventDeviceType::ACPIOtherInput))
 			&& (keycode == KEY_POWER)) {
 			TQTimer::singleShot(50, this, TQT_SLOT(emitPowerButtonPressed()));
-		} else if (((edevice->eventType() == TDEEventDeviceType::ACPISleepButton) || (edevice->eventType() == TDEEventDeviceType::ACPIOtherInput))
+		} else if (((edevice->eventType() == TDEEventDeviceType::ACPISuspendButton) || (edevice->eventType() == TDEEventDeviceType::ACPIOtherInput))
 			&& (keycode == KEY_SLEEP)) {
-			TQTimer::singleShot(50, this, TQT_SLOT(emitSleepButtonPressed()));
+			TQTimer::singleShot(50, this, TQT_SLOT(emitSuspendButtonPressed()));
 		} else if (((edevice->eventType() == TDEEventDeviceType::ACPISuspendButton) || (edevice->eventType() == TDEEventDeviceType::ACPIOtherInput))
 			&& (keycode == KEY_SUSPEND)) {
 			TQTimer::singleShot(50, this, TQT_SLOT(emitS2diskButtonPressed()));
@@ -212,9 +213,6 @@ void HardwareInfo::processKeyPressEvent(unsigned int keycode, TDEEventDevice* ed
 // 			else if (!brightness_in_hardware && value.endsWith("-down"))
 // 				TQTimer::singleShot(50, this, TQT_SLOT(brightnessDownPressed()));
 		}
-// 	} else {
-// 		kdDebug() << "Unmonitored HAL_CONDITION: " << message << " : " << value << endl;
-// 	}
 
 	kdDebugFuncOut(trace);
 }
@@ -268,7 +266,7 @@ bool HardwareInfo::checkIfHandleDevice ( TQString _udi, int *type) {
 					*type = LID;
 				} else if (edevice->eventType() == TDEEventDeviceType::ACPIPowerButton) {
 					*type = BUTTON_POWER;
-				} else if (edevice->eventType() == TDEEventDeviceType::ACPISleepButton) {
+				} else if (edevice->eventType() == TDEEventDeviceType::ACPISuspendButton) {
 					*type = BUTTON_SLEEP;
 				} else {
 					ret = false;
@@ -390,6 +388,9 @@ void HardwareInfo::checkSuspend() {
 	suspend_states.standby = false;
 	suspend_states.standby_can = false;
 	suspend_states.standby_allowed = -1;
+	suspend_states.suspend_hybrid = false;
+	suspend_states.suspend_hybrid_can = false;
+	suspend_states.suspend_hybrid_allowed = -1;
 
 	TDERootSystemDevice* rdevice = m_hwdevices->rootSystemDevice();
 	TDESystemPowerStateList powerStates = rdevice->powerStates();
@@ -399,27 +400,32 @@ void HardwareInfo::checkSuspend() {
 			if ((*it) == TDESystemPowerState::Active) {
 				//
 			}
-			if ((*it) == TDESystemPowerState::Standby) {
+			else if ((*it) == TDESystemPowerState::Standby) {
 				suspend_states.standby = true;
 				suspend_states.standby_allowed = rdevice->canStandby();
-				suspend_states.standby_can = suspend_states.standby_allowed & suspend_states.standby;
+				suspend_states.standby_can = suspend_states.standby_allowed && suspend_states.standby;
 			}
-			if ((*it) == TDESystemPowerState::Freeze) {
+			else if ((*it) == TDESystemPowerState::Freeze) {
 				suspend_states.freeze = true;
 				suspend_states.freeze_allowed = rdevice->canFreeze();
-				suspend_states.freeze_can = suspend_states.freeze_allowed & suspend_states.freeze;
+				suspend_states.freeze_can = suspend_states.freeze_allowed && suspend_states.freeze;
 			}
-			if ((*it) == TDESystemPowerState::Suspend) {
+			else if ((*it) == TDESystemPowerState::Suspend) {
 				suspend_states.suspend2ram = true;
 				suspend_states.suspend2ram_allowed = rdevice->canSuspend();
-				suspend_states.suspend2ram_can = suspend_states.suspend2ram_allowed & suspend_states.suspend2ram;
+				suspend_states.suspend2ram_can = suspend_states.suspend2ram_allowed && suspend_states.suspend2ram;
 			}
-			if ((*it) == TDESystemPowerState::Hibernate) {
+			else if ((*it) == TDESystemPowerState::Hibernate) {
 				suspend_states.suspend2disk = true;
 				suspend_states.suspend2disk_allowed = rdevice->canHibernate();
-				suspend_states.suspend2disk_can = suspend_states.suspend2disk_allowed & suspend_states.suspend2disk;
+				suspend_states.suspend2disk_can = suspend_states.suspend2disk_allowed && suspend_states.suspend2disk;
 			}
-			if ((*it) == TDESystemPowerState::PowerOff) {
+			else if ((*it) == TDESystemPowerState::HybridSuspend) {
+				suspend_states.suspend_hybrid = true;
+				suspend_states.suspend_hybrid_allowed = rdevice->canHybridSuspend();
+				suspend_states.suspend_hybrid_can = suspend_states.suspend_hybrid_allowed && suspend_states.suspend_hybrid;
+			}
+			else if ((*it) == TDESystemPowerState::PowerOff) {
 				//
 			}
 		}
@@ -794,13 +800,34 @@ bool HardwareInfo::suspend( suspend_type suspend ) {
 					}
 				} else {
 					if ( !suspend_states.suspend2disk )
-						kdDebug() << "The machine does not support suspend to disk." << endl;
+						kdDebug() << "The machine does not support hibernation." << endl;
 					else
-						kdWarning() << "Policy forbid user to trigger suspend to disk" << endl;
+						kdWarning() << "Policy forbid user to trigger hibernation" << endl;
 
 					return false;
 				}
 				break;
+				
+			case SUSPEND_HYBRID:
+				if (suspend_states.suspend_hybrid && (suspend_states.suspend_hybrid_allowed != 0)) {
+					if (rdevice->setPowerState(TDESystemPowerState::HybridSuspend)) {
+						calledSuspend.start();
+						handleResumeSignal(0);
+						return true;
+					} else {
+						handleResumeSignal(-1);
+						return false;
+					}
+				} else {
+					if ( !suspend_states.suspend_hybrid )
+						kdDebug() << "The machine does not support hybrid suspension." << endl;
+					else
+						kdWarning() << "Policy forbid user to trigger hybrid suspension" << endl;
+
+					return false;
+				}
+				break;
+			
 			case SUSPEND2RAM:
 				if (suspend_states.suspend2ram && (suspend_states.suspend2ram_allowed != 0)) {
 					if (rdevice->setPowerState(TDESystemPowerState::Suspend)) {
@@ -813,13 +840,14 @@ bool HardwareInfo::suspend( suspend_type suspend ) {
 					}
 				} else {
 					if ( !suspend_states.suspend2ram )
-						kdDebug() << "The machine does not support suspend to ram." << endl;
+						kdDebug() << "The machine does not support Suspend mode." << endl;
 					else
-						kdWarning() << "Policy forbid user to trigger suspend to ram" << endl;
+						kdWarning() << "Policy forbid user to trigger Suspend mode" << endl;
 
 					return false;
 				}
 				break;
+				
 			case FREEZE:
 				if (suspend_states.freeze && (suspend_states.freeze_allowed != 0)) {
 					if (rdevice->setPowerState(TDESystemPowerState::Freeze)) {
@@ -839,6 +867,7 @@ bool HardwareInfo::suspend( suspend_type suspend ) {
 					return false;
 				}
 				break;
+				
 			case STANDBY:
 				if (suspend_states.standby && (suspend_states.standby_allowed != 0)) {
 					if (rdevice->setPowerState(TDESystemPowerState::Standby)) {
@@ -858,6 +887,7 @@ bool HardwareInfo::suspend( suspend_type suspend ) {
 					return false;
 				}
 				break;
+				
 			default:
 				return false;
 		}
@@ -1050,9 +1080,9 @@ bool HardwareInfo::setCPUFreqGovernor( const char *governor ) {
 // --> TDE hardware library method call (trigger actions) section -- END <---
 
 // --> private helper functions/slots to forward/handle events  -- START <--
-//     need this functions to make events from HAL/D-Bus independent
-//     from QT event loop and to allow QT3 D-Bus bindings to get not
-//     blocked by normal KDE/QT (GUI) calls
+//     need this functions to make events independent
+//     from TQt event loop and to allow TQt3 D-Bus bindings to get not
+//     blocked by normal TDE/TQt (GUI) calls
 /*!
  * Function to emit the signal for the Power button.
  */
@@ -1065,9 +1095,9 @@ void HardwareInfo::emitPowerButtonPressed() {
 }
 
 /*!
- * Function to emit the signal for the Sleep button.
+ * Function to emit the signal for the Suspend button.
  */
-void HardwareInfo::emitSleepButtonPressed() {
+void HardwareInfo::emitSuspendButtonPressed() {
 	if (sessionIsActive) {
 		emit sleepButtonPressed();
 	} else {
