@@ -26,6 +26,10 @@
  * \author 	Danny Kukawka, <dkukawka@suse.de>, <danny.kukawka@web.de>
  * \date    	2004 - 2006
  */
+
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
  
  // own headers
 #include "screen.h"
