@@ -19,6 +19,10 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // KDE headers:
 #include <tdeaboutapplication.h>
 #include <tdeapplication.h>
@@ -75,12 +79,12 @@ tdepowersave::tdepowersave( bool force_acpi_check, bool trace_func ) : KSystemTr
 		config->writeEntry("AlreadyStarted", true);
 		// check whether APM, ACPI, PMU, CPUFreq or Suspend2Disk/ram supported, otherwise end up
 		// and don't start tdepowersave ever again until force_acpi_check == true.
-		if (!hwinfo->hasACPI() && !hwinfo->hasAPM() && !hwinfo->hasPMU() &&
-		    !hwinfo->supportCPUFreq() && !suspend.suspend2disk && !suspend.suspend2ram){
+		if (!hwinfo->hasACPI() && !hwinfo->hasAPM() && !hwinfo->hasPMU() && !hwinfo->supportCPUFreq() &&
+		     !suspend.suspend2disk && !suspend.suspend2ram && !suspend.suspend_hybrid) {
 			config->writeEntry("Autostart", false);
 			config->sync();
-			kdError() << "This machine does not support ACPI, APM, PMU, CPUFreq, Suspend2Disk nor "
-			          << "Suspend2RAM. Please close tdepowersave now." << endl;
+			kdError() << "This machine does not support ACPI, APM, PMU, CPUFreq, Suspend2Disk, "
+			          << "Suspend2RAM nor Hybrid Suspend. Please close tdepowersave now." << endl;
 			exit(-1);
 		}
 	}
@@ -108,7 +112,7 @@ tdepowersave::tdepowersave( bool force_acpi_check, bool trace_func ) : KSystemTr
 	// connect to events
 	connect(hwinfo, TQT_SIGNAL(lidclosetStatus(bool)), this, TQT_SLOT(handleLidEvent(bool)));
 	connect(hwinfo, TQT_SIGNAL(powerButtonPressed()), this, TQT_SLOT (handlePowerButtonEvent()));
-	connect(hwinfo, TQT_SIGNAL(sleepButtonPressed()), this, TQT_SLOT (handleSleepButtonEvent()));
+	connect(hwinfo, TQT_SIGNAL(sleepButtonPressed()), this, TQT_SLOT (handleSuspendButtonEvent()));
 	connect(hwinfo, TQT_SIGNAL(s2diskButtonPressed()), this, TQT_SLOT (handleS2DiskButtonEvent()));
 	connect(hwinfo, TQT_SIGNAL(batteryWARNState(int,int)), this, TQT_SLOT(notifyBatteryStatusChange (int,int)));
 	connect(hwinfo, TQT_SIGNAL(desktopSessionIsActive(bool)), this, TQT_SLOT (handleSessionState(bool)));
@@ -120,8 +124,8 @@ tdepowersave::tdepowersave( bool force_acpi_check, bool trace_func ) : KSystemTr
 	m_globalAccel = new TDEGlobalAccel( TQT_TQOBJECT(this) );
 	m_globalAccel->insert( "Power button", i18n( "Execute configured power button action"), TQString(),
 			TDEShortcut(TQString("XF86PowerOff")), TDEShortcut(TQString("XF86PowerOff")), TQT_TQOBJECT(this), TQT_SLOT( handlePowerButtonEvent() ) );
-	m_globalAccel->insert( "Sleep button", i18n( "Sleep configured power button action"), TQString(),
-			TDEShortcut(TQString("XF86Sleep")), TDEShortcut(TQString("XF86Sleep")), TQT_TQOBJECT(this), TQT_SLOT( handleSleepButtonEvent() ) );
+	m_globalAccel->insert( "Suspend button", i18n( "Suspend configured power button action"), TQString(),
+			TDEShortcut(TQString("XF86Suspend")), TDEShortcut(TQString("XF86Suspend")), TQT_TQOBJECT(this), TQT_SLOT( handleSuspendButtonEvent() ) );
 	m_globalAccel->insert( "Hibernate button", i18n( "Hibernate configured power button action"), TQString(),
 			TDEShortcut(TQString("XF86Suspend")), TDEShortcut(TQString("XF86Suspend")), TQT_TQOBJECT(this), TQT_SLOT( handleS2DiskButtonEvent() ) );
 	m_globalAccel->readSettings();
@@ -187,18 +191,16 @@ void tdepowersave::initMenu() {
 #endif
 
 	SLEEP_SEPARATOR_MENU_ID = this->contextMenu()->insertSeparator();
-	SUSPEND2DISK_MENU_ID = this->contextMenu()->insertItem( SmallIconSet("suspend_to_disk",
-								TQIconSet::Automatic),
-								i18n("Suspend to Disk"), this,
-								TQT_SLOT(do_suspend2disk()));
-	SUSPEND2RAM_MENU_ID = this->contextMenu()->insertItem( SmallIconSet("suspend_to_ram",
-							       TQIconSet::Automatic),
-							       i18n("Suspend to RAM"), this,
-							       TQT_SLOT(do_suspend2ram()));
 	FREEZE_MENU_ID = this->contextMenu()->insertItem( SmallIconSet("suspend_to_ram", TQIconSet::Automatic),
 							   i18n("Freeze"), this, TQT_SLOT(do_freeze()));
 	STANDBY_MENU_ID = this->contextMenu()->insertItem( SmallIconSet("stand_by", TQIconSet::Automatic),
 							   i18n("Standby"), this, TQT_SLOT(do_standby()));
+	SUSPEND2RAM_MENU_ID = this->contextMenu()->insertItem( SmallIconSet("suspend_to_ram",
+							       TQIconSet::Automatic), i18n("Suspend"), this, TQT_SLOT(do_suspend2ram()));
+	SUSPEND2DISK_MENU_ID = this->contextMenu()->insertItem( SmallIconSet("suspend_to_disk",
+								TQIconSet::Automatic), i18n("Hibernate"), this, TQT_SLOT(do_suspend2disk()));
+	SUSPEND_HYBRID_MENU_ID = this->contextMenu()->insertItem( SmallIconSet("suspend_to_disk",
+								TQIconSet::Automatic), i18n("Hybrid Suspend"), this, TQT_SLOT(do_suspend_hybrid()));
 
 	speed_menu = new TQPopupMenu(this, i18n("Set CPU Frequency Policy").utf8());
 	speed_menu->insertItem(i18n("Performance"), PERFORMANCE);
@@ -659,7 +661,7 @@ void tdepowersave::slotConfigProcessExited(TDEProcess *proc){
 
 /*!
  * \b TQT_SLOT to send the command for "suspend to disk" to TDE hardware library.
- * If there is a error while "suspend to disk" the user get e messagebox.
+ * If there is a error while "suspend to disk" the user get a messagebox.
  * This function need a power management backend in TDE hardware library for "suspend to disk".
  * \return boolean with the result of the operation
  * \retval true if successful
@@ -691,7 +693,7 @@ bool tdepowersave::do_suspend2disk(){
 				kdDebugFuncOut(trace);
 				return true;
 			} else {
-				KPassivePopup::message( i18n("WARNING"),i18n("Suspend to disk failed"),
+				KPassivePopup::message( i18n("WARNING"),i18n("Hibernation failed"),
 							SmallIcon("messagebox_warning", 20), this,
 							i18n("Warning").utf8(), 15000);
 				kdDebugFuncOut(trace);
@@ -699,7 +701,7 @@ bool tdepowersave::do_suspend2disk(){
 			}
 		} else {
 			KPassivePopup::message( i18n("WARNING"),
-						i18n("Suspend to disk disabled by administrator."),
+						i18n("Hibernation disabled by administrator."),
 						SmallIcon("messagebox_warning", 20),
 						this, i18n("Warning").utf8(), 15000);
 			this->contextMenu()->setItemEnabled(SUSPEND2DISK_MENU_ID, false);
@@ -707,7 +709,63 @@ bool tdepowersave::do_suspend2disk(){
 			return false;
 		}
 	} else {
-		kdWarning() << "This machine does not provide suspend to disk state" << endl;
+		kdWarning() << "This machine does not provide hibernation state" << endl;
+		kdDebugFuncOut(trace);
+		return false;
+	}
+}
+
+/*!
+ * \b TQT_SLOT to send the command for "hybrid suspend" to TDE hardware library.
+ * If there is a error while "hybrid suspend" the user get a messagebox.
+ * This function need a power management backend in TDE hardware library for "hybrid suspend".
+ * \return boolean with the result of the operation
+ * \retval true if successful
+ * \retval false if command not supported or if powersaved not running
+ */
+bool tdepowersave::do_suspend_hybrid(){
+	kdDebugFuncIn(trace);
+
+	if (suspend.suspend_hybrid) {
+		if (suspend.suspend_hybrid_allowed || suspend.suspend_hybrid_allowed == -1) {
+			calledSuspend = SUSPEND_HYBRID;
+			if (!handleMounts(true)) {
+				kdWarning() << "Could not umount ..." << endl;
+				calledSuspend = -1;
+				kdDebugFuncOut(trace);
+				return false;
+			}
+
+			if(settings->lockOnSuspend) {
+				display->lockScreen( settings->lockmethod );
+			}
+
+			autoSuspend->stop();
+			autoDimm->stop();
+			notifySuspend(calledSuspend);
+			bool ret = hwinfo->suspend(SUSPEND_HYBRID);
+
+			if (ret) {
+				kdDebugFuncOut(trace);
+				return true;
+			} else {
+				KPassivePopup::message( i18n("WARNING"),i18n("Hybrid Suspend failed"),
+							SmallIcon("messagebox_warning", 20), this,
+							i18n("Warning").utf8(), 15000);
+				kdDebugFuncOut(trace);
+				return false;
+			}
+		} else {
+			KPassivePopup::message( i18n("WARNING"),
+						i18n("Hybrid Suspend disabled by administrator."),
+						SmallIcon("messagebox_warning", 20),
+						this, i18n("Warning").utf8(), 15000);
+			this->contextMenu()->setItemEnabled(SUSPEND_HYBRID_MENU_ID, false);
+			kdDebugFuncOut(trace);
+			return false;
+		}
+	} else {
+		kdWarning() << "This machine does not provide hybrid suspend state" << endl;
 		kdDebugFuncOut(trace);
 		return false;
 	}
@@ -747,7 +805,7 @@ bool tdepowersave::do_suspend2ram(){
 				kdDebugFuncOut(trace);
 				return true;
 			} else {
-				KPassivePopup::message( i18n("WARNING"),i18n("Suspend to RAM failed"),
+				KPassivePopup::message( i18n("WARNING"),i18n("Suspend mode failed"),
 							SmallIcon("messagebox_warning", 20), this,
 							i18n("Warning").utf8(), 15000);
 				kdDebugFuncOut(trace);
@@ -755,7 +813,7 @@ bool tdepowersave::do_suspend2ram(){
 			}
 		} else {
 			KPassivePopup::message( i18n("WARNING"),
-						i18n("Suspend to RAM disabled by administrator."),
+						i18n("Suspend mode disabled by administrator."),
 						SmallIcon("messagebox_warning", 20), this,
 						i18n("Warning").utf8(), 15000);
 			this->contextMenu()->setItemEnabled(SUSPEND2RAM_MENU_ID, false);
@@ -763,7 +821,7 @@ bool tdepowersave::do_suspend2ram(){
 			return false;
 		}
 	} else {
-		kdWarning() << "This machine does not provide suspend to ram state" << endl;
+		kdWarning() << "This machine does not provide Suspend state" << endl;
 		kdDebugFuncOut(trace);
 		return false;
 	}
@@ -890,12 +948,17 @@ void tdepowersave::do_autosuspendWarn() {
 	// Verify that the desired suspend action is allowed before displaying the dialog
 	SuspendStates suspend = hwinfo->getSuspendSupport();
 	bool allowed = false;
-	if(settings->autoInactiveAction == "Suspend to Disk") {
+	if(settings->autoInactiveAction == "Hibernate") {
 		if ( suspend.suspend2disk && (suspend.suspend2disk_allowed || suspend.suspend2disk_allowed == -1)) {
 			allowed = true;
 		}
 	}
-	else if (settings->autoInactiveAction == "Suspend to RAM") {
+	else if(settings->autoInactiveAction == "Hybrid Suspend") {
+		if ( suspend.suspend_hybrid && (suspend.suspend_hybrid_allowed || suspend.suspend_hybrid_allowed == -1)) {
+			allowed = true;
+		}
+	}
+	else if (settings->autoInactiveAction == "Suspend") {
 		if( suspend.suspend2ram && (suspend.suspend2ram_allowed || suspend.suspend2ram_allowed == -1)) {
 			allowed = true;
 		}
@@ -919,9 +982,11 @@ void tdepowersave::do_autosuspendWarn() {
 
 				countdown = new countDownDialog(settings->autoSuspendCountdownTimeout);
 
-				if(settings->autoInactiveAction == "Suspend to Disk") {
+				if(settings->autoInactiveAction == "Hibernate") {
 					countdown->setPixmap("suspend2disk");
-				} else if (settings->autoInactiveAction == "Suspend to RAM") {
+				} else if(settings->autoInactiveAction == "Hybrid Suspend") {
+					countdown->setPixmap("suspend2disk");
+				} else if (settings->autoInactiveAction == "Suspend") {
 					countdown->setPixmap("suspend2ram");
 				} else if (settings->autoInactiveAction == "Freeze") {
 					countdown->setPixmap("suspend2ram");
@@ -963,8 +1028,6 @@ void tdepowersave::do_autosuspendWarn() {
  */
 bool tdepowersave::do_autosuspend(bool cancel) {
 	kdDebugFuncIn(trace);
-
-	// TODO: check if this is really needed, it get called also on the suspend methodes
 	autoSuspend->stop();
 
 	if (!cancel) {
@@ -974,9 +1037,11 @@ bool tdepowersave::do_autosuspend(bool cancel) {
 		}
 
 		if(settings->autoSuspend && !contextMenu()->isItemChecked(AUTOSUSPEND_MENU_ID)) {
-			if(settings->autoInactiveAction == "Suspend to Disk") {
+			if(settings->autoInactiveAction == "Hibernate") {
 				return do_suspend2disk();
-			} else if (settings->autoInactiveAction == "Suspend to RAM") {
+			} else if(settings->autoInactiveAction == "Hybrid Suspend") {
+				return do_suspend_hybrid();
+			} else if (settings->autoInactiveAction == "Suspend") {
 				return do_suspend2ram();
 			} else if (settings->autoInactiveAction == "Freeze") {
 				return do_freeze();
@@ -1208,7 +1273,7 @@ void tdepowersave::handlePowerButtonEvent( ) {
 /*!
  * Handle the event for the suspend2ram/sleep button and call the related action.
  */
-void tdepowersave::handleSleepButtonEvent() {
+void tdepowersave::handleSuspendButtonEvent() {
 	kdDebugFuncIn(trace);
 
 	// Only go to suspend on button event if we already resumed successful.
@@ -1424,10 +1489,11 @@ void tdepowersave::update(){
 		redraw_pixmap = 1;
 	}
 	if (!hwinfo->isOnline()){
-		this->contextMenu()->setItemVisible(SUSPEND2DISK_MENU_ID, false);
-		this->contextMenu()->setItemVisible(SUSPEND2RAM_MENU_ID, false);
 		this->contextMenu()->setItemVisible(FREEZE_MENU_ID, false);
 		this->contextMenu()->setItemVisible(STANDBY_MENU_ID, false);
+		this->contextMenu()->setItemVisible(SUSPEND2RAM_MENU_ID, false);
+		this->contextMenu()->setItemVisible(SUSPEND2DISK_MENU_ID, false);
+		this->contextMenu()->setItemVisible(SUSPEND_HYBRID_MENU_ID, false);
 		this->contextMenu()->setItemVisible(SLEEP_SEPARATOR_MENU_ID, false);
 		this->contextMenu()->setItemVisible(SCHEME_SEPARATOR_MENU_ID, false);
 		this->contextMenu()->setItemVisible(SCHEME_MENU_ID, false);
@@ -1447,10 +1513,11 @@ void tdepowersave::update(){
 			hwinfo->update_info_cpufreq_policy_changed = true;
 			suspend = hwinfo->getSuspendSupport();
 		}
-		this->contextMenu()->setItemVisible(SUSPEND2DISK_MENU_ID, true);
-		this->contextMenu()->setItemVisible(SUSPEND2RAM_MENU_ID, true);
 		this->contextMenu()->setItemVisible(FREEZE_MENU_ID, true);
 		this->contextMenu()->setItemVisible(STANDBY_MENU_ID, true);
+		this->contextMenu()->setItemVisible(SUSPEND2RAM_MENU_ID, true);
+		this->contextMenu()->setItemVisible(SUSPEND2DISK_MENU_ID, true);
+		this->contextMenu()->setItemVisible(SUSPEND_HYBRID_MENU_ID, true);
 		this->contextMenu()->setItemVisible(SLEEP_SEPARATOR_MENU_ID, true);
 		this->contextMenu()->setItemVisible(SCHEME_SEPARATOR_MENU_ID, true);
 		this->contextMenu()->setItemVisible(SCHEME_MENU_ID, true);
@@ -1468,6 +1535,16 @@ void tdepowersave::update(){
 				this->contextMenu()->setItemEnabled(SUSPEND2DISK_MENU_ID, false);
 		}
 
+		if (suspend.suspend_hybrid && (suspend.suspend_hybrid_allowed ||
+		    suspend.suspend_hybrid_allowed == -1)) {
+			this->contextMenu()->setItemEnabled(SUSPEND_HYBRID_MENU_ID, true);
+		} else {
+			if (!suspend.suspend_hybrid)
+				this->contextMenu()->setItemVisible(SUSPEND_HYBRID_MENU_ID, false);
+			else
+				this->contextMenu()->setItemEnabled(SUSPEND_HYBRID_MENU_ID, false);
+		}
+
 		if (suspend.suspend2ram && (suspend.suspend2ram_allowed ||
 		    suspend.suspend2ram_allowed == -1)) {
 			this->contextMenu()->setItemEnabled(SUSPEND2RAM_MENU_ID, true);
@@ -1870,12 +1947,17 @@ void tdepowersave::setAutoSuspend( bool resumed ){
 	// Verify that the desired suspend action is allowed before enabling autosuspend
 	SuspendStates suspend = hwinfo->getSuspendSupport();
 	bool allowed = false;
-	if(settings->autoInactiveAction == "Suspend to Disk") {
+	if(settings->autoInactiveAction == "Hibernate") {
 		if ( suspend.suspend2disk && (suspend.suspend2disk_allowed || suspend.suspend2disk_allowed == -1)) {
 			allowed = true;
 		}
 	}
-	else if (settings->autoInactiveAction == "Suspend to RAM") {
+	else if(settings->autoInactiveAction == "Hybrid Suspend") {
+		if ( suspend.suspend_hybrid && (suspend.suspend_hybrid_allowed || suspend.suspend_hybrid_allowed == -1)) {
+			allowed = true;
+		}
+	}
+	else if (settings->autoInactiveAction == "Suspend") {
 		if( suspend.suspend2ram && (suspend.suspend2ram_allowed || suspend.suspend2ram_allowed == -1)) {
 			allowed = true;
 		}
@@ -2116,6 +2198,9 @@ void tdepowersave::handleActionCall ( action action, int value , bool checkAC, b
 			case GO_SUSPEND2DISK:
 				TQTimer::singleShot(100, this, TQT_SLOT(do_suspend2disk()));
 				break;
+			case GO_SUSPEND_HYBRID:
+				TQTimer::singleShot(100, this, TQT_SLOT(do_suspend_hybrid()));
+				break;
 			case GO_FREEZE:
 				TQTimer::singleShot(100, this, TQT_SLOT(do_freeze()));
 				break;
@@ -2235,22 +2320,27 @@ void tdepowersave::notifySuspend( int suspendType ) {
 			case SUSPEND2DISK:
 				KNotifyClient::event( this->winId(), "suspend2disk_event",
 						      i18n("System is going into %1 now.").
-						      arg(i18n("Suspend to Disk")));
+						      arg(i18n("hibernation")));
+				break;
+			case SUSPEND_HYBRID:
+				KNotifyClient::event( this->winId(), "suspend_hybrid_event",
+						      i18n("System is going into %1 now.").
+						      arg(i18n("hybrid suspension")));
 				break;
 			case SUSPEND2RAM:
 				KNotifyClient::event( this->winId(), "suspend2ram_event",
 						      i18n("System is going into %1 now.").
-						      arg(i18n("Suspend to RAM")));
+						      arg(i18n("sleep")));
 				break;
 			case FREEZE:
 				KNotifyClient::event( this->winId(), "freeze_event",
 						      i18n("System is going into %1 now.").
-						      arg(i18n("Freeze")));
+						      arg(i18n("freeze")));
 				break;
 			case STANDBY:
 				KNotifyClient::event( this->winId(), "standby_event",
 						      i18n("System is going into %1 now.").
-						      arg(i18n("Standby")));
+						      arg(i18n("standby")));
 				break;
 			default:
 				break;
@@ -2300,22 +2390,27 @@ void tdepowersave::handleResumeSignal() {
 			case SUSPEND2DISK:
 				KNotifyClient::event( this->winId(), "resume_from_suspend2disk_event",
 						      i18n("System is resumed from %1.").arg(
-						      i18n("Suspend to Disk")));
+						      i18n("hibernation")));
+				break;
+			case SUSPEND_HYBRID:
+				KNotifyClient::event( this->winId(), "resume_from_suspend_hybrid_event",
+						      i18n("System is resumed from %1.").arg(
+						      i18n("hybrid suspension")));
 				break;
 			case SUSPEND2RAM:
 				KNotifyClient::event( this->winId(), "resume_from_suspend2ram_event",
 					      	      i18n("System is resumed from %1.").arg(
-						      i18n("Suspend to RAM")));
+						      i18n("sleep")));
 				break;
 			case FREEZE:
 				KNotifyClient::event( this->winId(), "resume_from_freeze_event",
 						      i18n("System is resumed from %1.").arg(
-						      i18n("Freeze")));
+						      i18n("freeze")));
 				break;
 			case STANDBY:
 				KNotifyClient::event( this->winId(), "resume_from_standby_event",
 						      i18n("System is resumed from %1.").arg(
-						      i18n("Standby")));
+						      i18n("standby")));
 				break;
 			default:
 				kdError() << "called suspend type unknown" << endl;
@@ -2357,6 +2452,10 @@ void tdepowersave::handleResumeSignal() {
 					logview = new LogViewer ("/var/log/suspend2disk.log");
 					logview->show();
 					break;
+				case SUSPEND_HYBRID:
+					logview = new LogViewer ("/var/log/suspend_hybrid.log");
+					logview->show();
+					break;
 				case SUSPEND2RAM:
 					logview = new LogViewer ("/var/log/suspend2ram.log");
 					logview->show();
@@ -2427,10 +2526,13 @@ TQString tdepowersave::getSuspendString (int type) {
 
 	switch (type) {
 		case SUSPEND2DISK:
-			return i18n("Suspend to Disk");
+			return i18n("Hibernate");
+			break;
+		case SUSPEND_HYBRID:
+			return i18n("Hybrid Suspend");
 			break;
 		case SUSPEND2RAM:
-			return i18n("Suspend to RAM");
+			return i18n("Suspend");
 			break;
 		case FREEZE:
 			return i18n("Freeze");
@@ -2580,6 +2682,10 @@ TQStringList tdepowersave::allowed_sleepingStates(){
 		    suspend.suspend2disk_allowed == -1)){
 			sleepList.append("suspendToDisk");
 		}
+		if (suspend.suspend_hybrid && (suspend.suspend_hybrid_allowed ||
+		    suspend.suspend_hybrid_allowed == -1)){
+			sleepList.append("suspendHybrid");
+		}
 		if (suspend.suspend2ram && (suspend.suspend2ram_allowed ||
 		    suspend.suspend2ram_allowed == -1)){
 			sleepList.append("suspendToRAM");
@@ -2664,6 +2770,18 @@ bool tdepowersave::do_suspendToDisk(){
 	return do_suspend2disk();
 }
 
+/*!
+ * DCOP Interface funtion to send the hybrid suspend command to powersave.
+ * \return boolean with the result of calling do_suspend_hybrid()
+ * \retval true if successful
+ * \retval false if not supported or powersaved not running
+ */
+bool tdepowersave::do_suspendHybrid(){
+	kdDebugFuncIn(trace);
+	kdDebugFuncOut(trace);
+	return do_suspend_hybrid();
+}
+
 /*!
  * DCOP Interface funtion to send the suspend to disk command to powersave.
  * \return boolean with the result of calling do_suspend2ram()
@@ -2781,7 +2899,7 @@ void tdepowersave::showDetailedDialog( ){
 /*!
  * DCOP Interface funtion to open the configure dialog.
  * \return boolean with the result of open the dialog
- * \retval false if failed (e.g. D-Bus or HAL is not running)
+ * \retval false if failed
  * \retval true if correct opend
  */
 bool tdepowersave::openConfigureDialog (){
