@@ -22,16 +22,6 @@
 #ifndef _TDEPOWERSAVE_H_
 #define _TDEPOWERSAVE_H_
 
-// this is needed to avoid typedef clash with X11/Xmd.h (X11/Xproto.h)
-#ifndef TQT_CLEAN_NAMESPACE
-#define TQT_CLEAN_NAMESPACE
-#endif
-
-// Global Header
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 // KDE - Header
 #include <kprocess.h>
 #include <ksystemtray.h>
@@ -188,6 +178,9 @@ private:
 	/*! contains the ID of the menuentry for suspend-to-disk */
 	int SUSPEND2DISK_MENU_ID;
 	//! a menu entry ID
+	/*! contains the ID of the menuentry for hybrid suspend */
+	int SUSPEND_HYBRID_MENU_ID;
+	//! a menu entry ID
 	/*! contains the ID of the menuentry for suspend-to-ram */
 	int SUSPEND2RAM_MENU_ID;
 	//! a menu entry ID
@@ -316,6 +309,8 @@ private slots:
 	bool do_suspend2disk();
 	//! send command for suspend_to_RAM to the TDE hardware library
 	bool do_suspend2ram();
+	//! send command for hybrid suspend to the TDE hardware library
+	bool do_suspend_hybrid();
 
 	//! show warning dialog or call autosuspend if signal \ref inactivity::inactivityTimeExpired() recieved
 	void do_autosuspendWarn();
@@ -377,7 +372,7 @@ private slots:
 	//! handle event for press power button and call action
 	void handlePowerButtonEvent();
 	//!  handle event for press s2ram/sleep button and call action
-	void handleSleepButtonEvent();
+	void handleSuspendButtonEvent();
 	//!  handle event for press s2disk button and call action
 	void handleS2DiskButtonEvent();
 
@@ -424,6 +419,8 @@ k_dcop:
 	bool do_setCPUFreqPolicy( TQString );
 	//! dcop function to send 'suspend to disk' command to powersaved
 	bool do_suspendToDisk();
+	//! dcop function to send 'hybrid suspend' command to powersaved
+	bool do_suspendHybrid();
 	//! dcop function to send 'suspend to RAM' command to powersaved
 	bool do_suspendToRAM();
 	//! dcop function to send 'freeze' command to powersaved
